;**********************************************************************
;				BADGE.ASM
;**********************************************************************

;DATE: JANUARY 12, 2009
;VERSION: A
;XTAL TYPE:  Internal 4 MHZ
;WRITTEN BY: RON NEWTON
;GENERAL REGISTER STARTS @ 07H
;INTERRUPT VECTOR =  NONE
;END OF PROGRAM MEMORY = 03FFH
;COMMENTS:  
;WHEN IR HITS IR DETECTOR,  LED LIGHTS AND BUZZER SOUNDS
;PUSHING THE RESET SWITCH RESETS THE PROGRAM
;PIEZO 4 KHZ
;
;**********************************************************
    
    list        p=12f508       	; list directive to define processor
	RADIX	DECIMAL						;YOU CAN CHANGE THIS TO DEC OR OCT DEFAULT IS HEX
    #include    <p12f508.inc>   	; processor specific variable definitions
    
	   __CONFIG  _MCLRE_OFF & _CP_OFF  & _WDT_OFF   & _IntRC_OSC  

; PORT DESCRIPTIONS
;
;

#DEFINE 	NAME		PORT			;PUT IN PORT AND NUMBER HERE E.G., PORTA,0 (NOTE COMMA)
#DEFINE		PHOTO		GPIO,0
#DEFINE		LED			GPIO,2
#DEFINE		RESET		GPIO,3
#DEFINE		SOUND		GPIO,4


;NEW REGISTERS
COUNT		EQU		07H					;COUNTING REGISTER
COUNT1		EQU		08H					;COUNT 1 REGISTER
COUNTER		EQU		09H					;COUNTER REGISTER
COUNTER1	EQU		0AH					;COUNTER 1 REGISTER
COUNTER2	EQU		0BH					;COUNTER 2 REGISTER
HITS		EQU		0CH					;HIT REGISTER

	ORG		0H							;START OF PROGRAM OR RESET
START	MOVLW		B'0001001'			;PROGRAM GPIO FOR INPUTS AND OUTPUTS
		TRIS		GPIO				;LOAD GPIO
		MOVLW		0					;PUT IN ZERO IN W
		OPTION							;LOAD OPTION REGISTER
		MOVLW		.24					;PUT 24 INTO W
		MOVWF		COUNT				;LOAD COUNT	
		MOVLW		.10					;PUT 10 INTO W
		MOVWF		COUNTER1			;LOAD COUNTER 1
		CLRF		COUNTER2			;CLEAR COUNTER 2

S1		BSF			LED					;TURN OFF LED
		BCF			SOUND				;TURN OFF SOUND
	    BTFSS		RESET				;CHECK TO SEE IF RESET IS PUSHED
		CLRF		COUNTER2			;PUSHED CLEAR COUNTER 2

		BTFSC		PHOTO				;WAIT FOR IR
		GOTO		$-3					;NO IR GO BACK THREE STEPS

		INCF		COUNTER2,1			;IR DETECTED INCREASE COUNTER 2
		MOVF		COUNTER2,0			;MOVE COUNTER 2 INTO W
		MOVWF		HITS				;LOAD COUNTER 2 INTO HITS


S2		BCF			LED					;TURN ON LED
		BSF			SOUND				;TURN ON SOUND
S3		DECFSZ		COUNT,1				;KEEP BOTH ON FOR PERIOD OF TIME
		GOTO		$-1					;COUNT NOT ZERO GO BACK ONE

		MOVLW		.24					;RELOADING COUNT INTO W
		MOVWF		COUNT				;LOAD
		BCF			SOUND				;TURN OFF SOUND
		DECFSZ		COUNT,1				;DECREASE COUNT
		GOTO		$-1					;NOT ZERO JUMP BACK ONE
		MOVLW		.24					;RELOAD COUNT					
		MOVWF		COUNT				;LOAD
		DECFSZ		COUNTER,1			;DECREASE COUNTER
		GOTO		S2					;NOT ZERO GO BACK TO S2
		DECFSZ		COUNTER1,1			;DECREASE COUNTER 1
		GOTO		S2					;NOT ZERO GO BACK TO S2
		MOVLW		.200				;RELOAD COUNTER 1 WITH 200	
		MOVWF		COUNTER1			;LOAD		
		DECFSZ		COUNTER,1			;DECREASE COUNTER 
		GOTO		$-1					;NOT ZERO JUMP BACK 1
		DECFSZ		COUNTER1,1			;DECREASE COUNTER1
		GOTO		$-3					;NOT ZERO JUMP BACK 3
		MOVLW		.10					;LOAD 10 INTO COUNTER 1
		MOVWF		COUNTER1			;LOAD
		BSF			LED					;TURN OFF LED
		DECFSZ		HITS,1				;DECREASE HITS
		GOTO		S2					;NOT 10 YET GO BACK TO S2
		MOVLW		.10					;CHECKING TO SEE IF 10 HAS BEEN REACHED YET
		SUBWF		COUNTER2,0			;CHECKING TO SEE IF 10 HAS BEEN REACHED YET
		BTFSC		3,2					;CHECKING TO SEE IF 10 HAS BEEN REACHED YET
		GOTO		S5					;10 JUMP TO S5
		GOTO		S1					;NOT 10 GO TO S1
S5	    BTFSC		RESET				;CHECK TO SEE IF RESET IS PUSHED
		GOTO		S5					;10 HITS GO BACK TO S5
		CLRF		COUNTER2			;PUSHED CLEAR COUNTER 2
		GOTO		S1					;GO BACK TO S1 AND START OVER

    END                       		; directive 'end of program'